@@ -1,4 +1,4 @@
-#! /usr/bin/env python
+#! /usr/bin/env python3
 # -*- coding: utf-8 -*-
 # filename: totalopenstation-gui.py
 # Copyright 2008-2019 Stefano Costa <steko@iosa.it>
@@ -174,11 +174,11 @@ class ConnectDialog(tkinter.simpledialog.Dialog):
         tkinter.simpledialog.Dialog.__init__(self, parent)
 
     def body(self, master):
-        title = _("waiting for data from device")
+        title = _("Waiting for data from device")
         message1 = _("Connection initialized with the following parameters:\n")
         params = "%s\n" % self.conn_str
         message2 = _("\nStart the download procedure on the device.\n")
-        message2 = message2 + _("Press OK when done.")
+        message2 += _("Press OK when done.")
         Label(master, bitmap="hourglass").pack()
         Label(master, text=title, font=("Helvetica", "16", "bold")).pack()
         Label(master, text=message1).pack()
@@ -225,7 +225,7 @@ class ProcessDialog(tkinter.simpledialog.Dialog):
         self.input_format = StringVar()
         self.input_format.set(self.format)
         input_format_entry = Menubutton(input_frame,
-                                        text=_("choose a format"),
+                                        text=_("Choose a format"),
                                         textvariable=self.input_format,
                                         relief=RAISED,
                                         width=24)
@@ -244,7 +244,7 @@ class ProcessDialog(tkinter.simpledialog.Dialog):
         self.output_format = StringVar()
         self.output_format.set(self.format)
         output_format_entry = Menubutton(output_frame,
-                                        text=_("choose a format"),
+                                        text=_("Choose a format"),
                                         textvariable=self.output_format,
                                         relief=RAISED,
                                         width=24)
@@ -276,10 +276,10 @@ class ProcessDialog(tkinter.simpledialog.Dialog):
                 # builtin format parser
                 mod, cls, name = inputclass
                 inputclass = getattr(
-                    __import__('totalopenstation.formats.' + mod, None, None, [cls]), cls)
+                    __import__('totalopenstation.formats.%s' % mod, None, None, [cls]), cls)
             except ImportError as msg:
                 showwarning(_('Import error'),
-                            _('Error loading the required input module: %s' % msg))
+                            _('Error loading the required input module: %s') % msg)
 
         # import output format writer
         of_lower = str(self.output_format.get()).lower()
@@ -289,10 +289,10 @@ class ProcessDialog(tkinter.simpledialog.Dialog):
                 # builtin output builder
                 mod, cls, name = outputclass
                 outputclass = getattr(
-                    __import__('totalopenstation.output.' + mod, None, None, [cls]), cls)
+                    __import__('totalopenstation.output.%s' % mod, None, None, [cls]), cls)
             except ImportError as msg:
                 showwarning(_('Import error'),
-                            _('Error loading the required output module: %s' % msg))
+                            _('Error loading the required output module: %s') % msg)
 
         # no point in parsing before the output format has been imported
         parsed_data = inputclass(self.data)
@@ -388,9 +388,9 @@ class Tops:
         languagemenu.add_radiobutton(label="Italiano",variable=language,value="it")
 
         self.menubar.add_cascade(label="Total Station", menu=topsmenu)
-        self.menubar.add_cascade(label="File", menu=filemenu)
+        self.menubar.add_cascade(label=_("File"), menu=filemenu)
         #self.menubar.add_cascade(label="Language", menu=languagemenu)
-        self.menubar.add_cascade(label="Help", menu=helpmenu)
+        self.menubar.add_cascade(label=_("Help"), menu=helpmenu)
 
         self.upper_frame = Frame(self.main_frame) ###
         self.upper_frame.pack(side=TOP, expand=NO, padx=10,
@@ -478,7 +478,7 @@ class Tops:
         self.optionMODEL_value.set(self.upref.getvalue('model'))
 
         self.optionMODEL_entry = Menubutton(self.optionMODEL_frame,
-                                        text="choose a model",
+                                        text=_("Choose a model"),
                                         textvariable=self.optionMODEL_value,
                                         relief=RAISED,
                                         width=20)
@@ -498,7 +498,7 @@ class Tops:
         self.option2_frame.pack(side=TOP)
 
         self.option2_label = Label(self.option2_frame,
-                                   text="Baudrate",
+                                   text=_("Baudrate"),
                                    width=30)
         self.option2_label.pack(side=LEFT)
         self.option2_value = IntVar()
@@ -512,7 +512,7 @@ class Tops:
                                        width=20)
         else:
             self.option2_entry = Menubutton(self.option2_frame,
-                                            text=_("choose a value"),
+                                            text=_("Choose a value"),
                                             textvariable=self.option2_value,
                                             relief=RAISED,
                                             width=20)
@@ -537,7 +537,7 @@ class Tops:
         self.option3_label.pack(side=LEFT, anchor=E)
         self.option3_value = IntVar()
         self.option3_entry = Menubutton(self.option3_frame,
-                                        text=_("choose a value"),
+                                        text=_("Choose a value"),
                                         textvariable=self.option3_value,
                                         relief=RAISED,
                                         width=20)
@@ -560,7 +560,7 @@ class Tops:
         self.option4_label.pack(side=LEFT, anchor=E)
         self.option4_value = StringVar()
         self.option4_entry = Menubutton(self.option4_frame,
-                                        text=_("choose a value"),
+                                        text=_("Choose a value"),
                                         textvariable=self.option4_value,
                                         relief=RAISED,
                                         width=20)
@@ -583,7 +583,7 @@ class Tops:
         self.option5_label.pack(side=LEFT, anchor=E)
         self.option5_value = IntVar()
         self.option5_entry = Menubutton(self.option5_frame,
-                                        text=_("choose a value"),
+                                        text=_("Choose a value"),
                                         textvariable=self.option5_value,
                                         relief=RAISED,
                                         width=20)
@@ -640,7 +640,7 @@ class Tops:
         self.process_button.bind("<Return>", self.process_action)
 
         self.status = StatusBar(self.main_frame)
-        self.status.set('Welcome to Total Open Station')
+        self.status.set(_('Welcome to Total Open Station'))
         self.status.pack(side=BOTTOM, fill=X)
 
         # text frame
@@ -672,7 +672,7 @@ class Tops:
     def on_app_close(self):
         '''Callback function to ask for confirmation before quitting the application.'''
 
-        if askokcancel("Quit","Do you really want to quit application ?"):
+        if askokcancel(_("Quit"), _("Do you really want to quit application ?")):
             self.myParent.destroy()
 
     def exit_action(self, event):
@@ -721,10 +721,10 @@ class Tops:
                     # builtin model builder
                     mod, cls, name = modelclass
                     modelclass = getattr(
-                        __import__('totalopenstation.models.' + mod, None, None, [cls]), cls)
+                        __import__('totalopenstation.models.%s' % mod, None, None, [cls]), cls)
                 except ImportError as msg:
                     showwarning(_('Import error'),
-                                _('Error loading the required model module: %s' % msg))
+                                _('Error loading the required model module: %s') % msg)
 
                 mc = modelclass(chosen_port, **self.options)
 
@@ -748,7 +748,7 @@ class Tops:
                         while mc.inWaiting() > 0:
                             newdata = mc.read(mc.inWaiting())
                             result += newdata
-                            self.status.set(_('Downloaded %d bytes'), len(result))
+                            self.status.set(_('Downloaded %d bytes') % len(result))
                             self.replace_text(result.decode())
                             sleep(sleeptime) # TODO determine sleep time from baudrate
                         mc.close()
