@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # filename: formats/__init__.py
 # Copyright 2008-2009 Luca Bianconi <luxetluc@yahoo.it>
-# Copyright 2008-2011 Stefano Costa <steko@iosa.it>
+# Copyright 2023 Stefano Costa <steko@iosa.it>
 
 # This file is part of Total Open Station.
 
@@ -51,7 +51,7 @@ class Connector(serial.Serial, Thread):
                 writeTimeout=None, dsrdtr=None):
 
         self.upref = UserPrefs()
-        sleeptime = float(self.upref.getvalue('sleeptime'))
+        self.sleeptime = float(self.upref.getvalue('sleeptime'))
 
         Thread.__init__(self)
         self.dl_started = Event()
@@ -81,11 +81,11 @@ class Connector(serial.Serial, Thread):
         # looks like there is a maximum buffer of 4096 characters, so we have
         # to wait for a short time and iterate the process until finished
 
-        sleep(sleeptime)
+        sleep(self.sleeptime)
 
         while self.inWaiting() > 0:
             result = result + self.read(self.inWaiting())
-            sleep(sleeptime)
+            sleep(self.sleeptime)
 
         self.result = result
 
@@ -98,14 +98,10 @@ class Connector(serial.Serial, Thread):
         '''
 
         while self.inWaiting() == 0:
-            sleep(sleeptime)
+            sleep(self.sleeptime)
         self.dl_started.set()
-        try:
-            self.download()
-        except threading.exceptions.KeyboardInterrupt:
-            sys.exit()
-        else:
-            self.dl_finished.set()
+        self.download()
+        self.dl_finished.set()
 
     def run(self):
         self.fast_download()
@@ -114,8 +110,10 @@ class Connector(serial.Serial, Thread):
 BUILTIN_MODELS = {
     'leica_tcr_1205': ('leica_tcr_1205', 'ModelConnector', 'Leica TCR 1205'),
     'zeiss_elta_r55': ('zeiss_elta_r55', 'ModelConnector', 'Zeiss Elta R55'),
+    'nikon_npl_322plus': ('nikon_npl_322plus', 'ModelConnector','Nikon NPL 322+'),
     'nikon_npl_350': ('nikon_npl_350', 'ModelConnector','Nikon NPL 350'),
     'leica_tcr_705': ('leica_tcr_705', 'ModelConnector', 'Leica TCR 705'),
-    'trimble': ('trimble', 'ModelConnector', 'Trimble'),
+    'trimble': ('trimble', 'ModelConnector', 'Trimble'), 
+    'topcon_gpt_3005': ('topcon_gpt_3005', 'ModelConnector', 'Topcon GPT 3005'),
     'custom': ('custom', 'CustomConnector', 'Custom/Unknown'),
     }
